MethodChannelSsPreventer class

Inheritance

Constructors

MethodChannelSsPreventer()

Properties

eventChannel EventChannel
final
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshotStream Stream<ScreenshotEvent>
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventOff() Future<void>
override
preventOn() Future<void>
override
setDetectionEnabled(bool enabled) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited